import type { BinaryFileType, IDisplayOptions, INodeProperties, JsonObject } from './Interfaces';
export declare const isObjectEmpty: (obj: object | null | undefined) => boolean;
export type Primitives = string | number | boolean | bigint | symbol | null | undefined;
export declare const deepCopy: <T extends Primitives | ((object | Date) & {
    toJSON?: (() => string) | undefined;
})>(source: T, hash?: WeakMap<object, any>, path?: string) => T;
type MutuallyExclusive<T, U> = (T & {
    [k in Exclude<keyof U, keyof T>]?: never;
}) | (U & {
    [k in Exclude<keyof T, keyof U>]?: never;
});
type JSONParseOptions<T> = MutuallyExclusive<{
    errorMessage: string;
}, {
    fallbackValue: T;
}>;
export declare const jsonParse: <T>(jsonString: string, options?: JSONParseOptions<T>) => T;
type JSONStringifyOptions = {
    replaceCircularRefs?: boolean;
};
export declare const replaceCircularReferences: <T>(value: T, knownObjects?: WeakSet<object>) => T;
export declare const jsonStringify: (obj: unknown, options?: JSONStringifyOptions) => string;
export declare const sleep: (ms: number) => Promise<void>;
export declare function fileTypeFromMimeType(mimeType: string): BinaryFileType | undefined;
export declare function assert<T>(condition: T, msg?: string): asserts condition;
export declare const isTraversableObject: (value: any) => value is JsonObject;
export declare const removeCircularRefs: (obj: JsonObject, seen?: Set<unknown>) => void;
export declare function updateDisplayOptions(displayOptions: IDisplayOptions, properties: INodeProperties[]): {
    displayOptions: IDisplayOptions;
    displayName: string;
    name: string;
    type: import("./Interfaces").NodePropertyTypes;
    typeOptions?: import("./Interfaces").INodePropertyTypeOptions | undefined;
    default: import("./Interfaces").NodeParameterValueType;
    description?: string | undefined;
    hint?: string | undefined;
    options?: (import("./Interfaces").INodePropertyOptions | INodeProperties | import("./Interfaces").INodePropertyCollection)[] | undefined;
    placeholder?: string | undefined;
    isNodeSetting?: boolean | undefined;
    noDataExpression?: boolean | undefined;
    required?: boolean | undefined;
    routing?: import("./Interfaces").INodePropertyRouting | undefined;
    credentialTypes?: ("extends:oAuth2Api" | "extends:oAuth1Api" | "has:authenticate" | "has:genericAuth")[] | undefined;
    extractValue?: import("./Interfaces").INodePropertyValueExtractorRegex | undefined;
    modes?: import("./Interfaces").INodePropertyMode[] | undefined;
    requiresDataPath?: "single" | "multiple" | undefined;
    doNotInherit?: boolean | undefined;
    validateType?: import("./Interfaces").FieldType | undefined;
    ignoreValidationDuringExecution?: boolean | undefined;
}[];
export {};
